@@ -1,6 +1,7 @@
 /*
  *
  * Copyright (C) 2005-2008 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2010 Michal Malek <michalm@jabster.pl>
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
@@ -21,27 +22,26 @@
 #include "k3bapplication.h"
 #include "k3bmediacache.h"
 
-#include <KAction>
-#include <KActionCollection>
-#include <KInputDialog>
+#include <KI18n/KLocalizedString>
 #include <KIO/Job>
-#include <KLocale>
-#include <KMessageBox>
-
+#include <KWidgetsAddons/KMessageBox>
+#include <KXmlGui/KActionCollection>
 #include <Solid/Block>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 
+#include <QtWidgets/QAction>
+#include <QtWidgets/QInputDialog>
 
 class K3b::AppDeviceManager::Private
 {
 public:
-    KAction* actionDiskInfo;
-    KAction* actionUnmount;
-    KAction* actionMount;
-    KAction* actionEject;
-    KAction* actionLoad;
-    KAction* actionSetReadSpeed;
+    QAction* actionDiskInfo;
+    QAction* actionUnmount;
+    QAction* actionMount;
+    QAction* actionEject;
+    QAction* actionLoad;
+    QAction* actionSetReadSpeed;
 
     K3b::Device::Device* currentDevice;
 };
@@ -61,9 +61,9 @@ K3b::AppDeviceManager::AppDeviceManager( QObject* parent )
                                       actionCollection(), "device_eject");
     d->actionLoad = K3b::createAction(this, i18n("L&oad"), 0, 0, this, SLOT(loadDisk()),
                                      actionCollection(), "device_load");
-//   KAction* actionUnlock = new KAction( i18n("Un&lock"), "", 0, this, SLOT(unlockDevice()),
+//   QAction* actionUnlock = new QAction( i18n("Un&lock"), "", 0, this, SLOT(unlockDevice()),
 // 				       actionCollection(), "device_unlock" );
-//   KAction* actionlock = new KAction( i18n("Loc&k"), "", 0, this, SLOT(lockDevice()),
+//   QAction* actionlock = new QAction( i18n("Loc&k"), "", 0, this, SLOT(lockDevice()),
 // 				     actionCollection(), "device_lock" );
     d->actionSetReadSpeed = K3b::createAction(this, i18n("Set Read Speed..."), 0, 0, this, SLOT(setReadSpeed()),
                                              actionCollection(), "device_set_read_speed" );
@@ -125,13 +125,15 @@ K3b::Device::Device* K3b::AppDeviceManager::addDevice( const Solid::Device& soli
 
 void K3b::AppDeviceManager::removeDevice( const Solid::Device& solidDev )
 {
-    if( findDevice( solidDev.as<Solid::Block>()->device() ) == currentDevice() )
-        setCurrentDevice( 0 );
+    if( const Solid::Block* blockDevice = solidDev.as<Solid::Block>() ) {
+        if( findDevice( blockDevice->device() ) == currentDevice() )
+            setCurrentDevice( 0 );
 
-    K3b::Device::DeviceManager::removeDevice( solidDev );
+        K3b::Device::DeviceManager::removeDevice( solidDev );
 
-    if( currentDevice() == 0 && !allDevices().isEmpty() )
-        setCurrentDevice( allDevices().first() );
+        if( currentDevice() == 0 && !allDevices().isEmpty() )
+            setCurrentDevice( allDevices().first() );
+    }
 }
 
 
@@ -149,18 +151,18 @@ void K3b::AppDeviceManager::slotMediumChanged( K3b::Device::Device* dev )
             d->actionMount->setEnabled( mediumMountable );
             d->actionUnmount->setEnabled( mediumMountable );
 
-            disconnect( this, SLOT(slotMountChanged(bool,const QString&)) );
-            disconnect( this, SLOT(slotMountFinished(Solid::ErrorType,QVariant,const QString&)) );
-            disconnect( this, SLOT(slotUnmountFinished(Solid::ErrorType,QVariant,const QString&)) );
+            disconnect( this, SLOT(slotMountChanged(bool,QString)) );
+            disconnect( this, SLOT(slotMountFinished(Solid::ErrorType,QVariant,QString)) );
+            disconnect( this, SLOT(slotUnmountFinished(Solid::ErrorType,QVariant,QString)) );
 
             Solid::StorageAccess* storage = dev->solidStorage();
             if( storage != 0 ) {
-                connect( storage, SIGNAL(accessibilityChanged(bool,const QString&)),
-                        this, SLOT(slotMountChanged(bool,const QString&)) );
-                connect( storage, SIGNAL(setupDone(Solid::ErrorType,QVariant,const QString&)),
-                        this, SLOT(slotMountFinished(Solid::ErrorType,QVariant,const QString&)) );
-                connect( storage, SIGNAL(teardownDone(Solid::ErrorType,QVariant,const QString&)),
-                        this, SLOT(slotUnmountFinished(Solid::ErrorType,QVariant,const QString&)) );
+                connect( storage, SIGNAL(accessibilityChanged(bool,QString)),
+                        this, SLOT(slotMountChanged(bool,QString)) );
+                connect( storage, SIGNAL(setupDone(Solid::ErrorType,QVariant,QString)),
+                        this, SLOT(slotMountFinished(Solid::ErrorType,QVariant,QString)) );
+                connect( storage, SIGNAL(teardownDone(Solid::ErrorType,QVariant,QString)),
+                        this, SLOT(slotUnmountFinished(Solid::ErrorType,QVariant,QString)) );
                 d->actionMount->setVisible( !storage->isAccessible() );
                 d->actionUnmount->setVisible( storage->isAccessible() );
             }
@@ -191,7 +193,7 @@ void K3b::AppDeviceManager::slotMountFinished( Solid::ErrorType error, QVariant,
     if( currentDevice() != 0 ) {
         Solid::StorageAccess* storage = currentDevice()->solidStorage();
         if( error == Solid::NoError && storage != 0 ) {
-            kDebug() << "Device mounted at " << storage->filePath();
+            qDebug() << "Device mounted at " << storage->filePath();
             emit mountFinished( storage->filePath() );
         }
     }
@@ -282,23 +284,22 @@ void K3b::AppDeviceManager::setReadSpeed()
 {
     if( currentDevice() ) {
         bool ok = false;
-        int s = KInputDialog::getInteger( i18n("CD Read Speed"),
-                                          i18n("<p>Please enter the preferred read speed for <b>%1</b>. "
-                                               "This speed will be used for the currently mounted "
-                                               "medium."
-                                               "<p>This is especially useful to slow down the drive when "
-                                               "watching movies which are read directly from the drive "
-                                               "and the spinning noise is intrusive."
-                                               "<p>Be aware that this has no influence on K3b since it will "
-                                               "change the reading speed again when copying CDs or DVDs."
-                                               ,currentDevice()->vendor() + " " + currentDevice()->description()),
-                                          12,
-                                          1,
-                                          currentDevice()->maxReadSpeed(),
-                                          1,
-                                          10,
-                                          &ok,
-                                          0 );
+        int s = QInputDialog::getInt( nullptr,
+                                      i18n("CD Read Speed"),
+                                      i18n("<p>Please enter the preferred read speed for <b>%1</b>. "
+                                           "This speed will be used for the currently mounted "
+                                           "medium."
+                                           "<p>This is especially useful to slow down the drive when "
+                                           "watching movies which are read directly from the drive "
+                                           "and the spinning noise is intrusive."
+                                           "<p>Be aware that this has no influence on K3b since it will "
+                                           "change the reading speed again when copying CDs or DVDs."
+                                           ,currentDevice()->vendor() + ' ' + currentDevice()->description()),
+                                      12,
+                                      1,
+                                      currentDevice()->maxReadSpeed(),
+                                      1,
+                                      &ok );
         if( ok ) {
             if( !currentDevice()->setSpeed( s*175, 0xFFFF ) )
                 KMessageBox::error( 0, i18n("Setting the read speed failed.") );
@@ -362,4 +363,4 @@ void K3b::AppDeviceManager::setReadSpeed( K3b::Device::Device* dev )
     setReadSpeed();
 }
 
-#include "k3bappdevicemanager.moc"
+
